import docker
from apisrun.utils.commons import singleton


@singleton
class ServiceDocker:
    """Service wrapper docker"""

    def __init__(self):
        """Init service docker"""
        self._client = docker.from_env()

    def run(
        self,
        image: str,
        name: str,
        network: str,
        environment: dict,
        ports: dict,
        labels: dict = {},
        detach: bool = True,
    ):
        """Run container."""
        try:
            container = self._client.containers.run(
                image=image,
                name=name,
                detach=detach,
                network=network,
                environment=environment,
                labels=labels,
                ports=ports,
            )
            return container
        except docker.errors.APIError:
            return None

    def get_or_create_network(self, name: str):
        try:
            if self._client.networks.get(name):
                return name
            return None
        except docker.errors.NotFound:
            obj = self._client.networks.create(name)
            return obj.name

    def get_container(self, name: str):
        """Get a container."""
        try:
            return self._client.containers.get(name)
        except docker.errors.APIError:
            return None

    def list(self, filters):
        """List containers."""
        return self._client.containers.list(filters=filters)

    def container_log(self):
        """Get logs of a container."""
        pass

    def stop(self):
        """Stop container."""
        pass


service_docker = ServiceDocker()
