# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apisrun',
 'apisrun.constants',
 'apisrun.resources',
 'apisrun.services',
 'apisrun.utils']

package_data = \
{'': ['*']}

install_requires = \
['bandit>=1.7.0,<2.0.0',
 'click>=8.0.1,<9.0.0',
 'docker>=5.0.2,<6.0.0',
 'flake8>=3.9.2,<4.0.0',
 'pytest-mock>=3.6.1,<4.0.0',
 'requests>=2.26.0,<3.0.0',
 'rich>=10.9.0,<11.0.0']

entry_points = \
{'console_scripts': ['apisrun = apisrun.main:cli']}

setup_kwargs = {
    'name': 'apisrun',
    'version': '0.0.3',
    'description': 'Apisrun CLI, is a tool to create microservices in an agile way.',
    'long_description': "# What's Apisrun ?\n\nApisrun is a tool to create microservices in an agile way. this CLI allows you to create one or more API through a manifest and a simple command.\n\n## Installation\n\n```bash\npip install apisrun\n```\n\n## How does it work\n\nTo start creating api we need to create a manifest. `apisrun.yml`\n\n```yml\n# This is an example manifest to create microservices in apisrun.\n\nmyapi: # Microservices name.\n\n  # first endpoint\n  - model: users # Model name.\n    path: /users/ # Path name.\n    schema: # Schema of data structure.\n      username:\n        type: string\n        required: true\n      age:\n        type: integer\n        required: true\n      is_admin:\n        type: boolean\n        required: true\n      level:\n        type: string\n\n  # second endpoint\n  - model: inventory # Model name.\n    path: /inventories/ # Path name.\n    schema: # Schema of data structure.\n      product:\n        type: string\n        required: true\n      value:\n        type: integer\n        required: true\n```\n\n* path: is the url that your new resource, must be unique.\n* schema: is the data structure to be persisted in the new resource. by default it is based on [cerberus](https://docs.python-cerberus.org/en/stable/index.html).\n* model: is the name that identifies your resource. must be unique.\n\n### Publishing microservices\n\n```bash\napisrun up -f examples/apisrun.yml\n\n🔄 Creating DB Container `myapi`.\n\U0001f7e2 DB Container `myapi` is ready and listening on port 27017.\n🔄 Creating Api Container `myapi`.\n\U0001f7e2 Api Container `myapi` is ready and listening on port 8000.\n🆙 Pushing data to Api `myapi`.\n```\n\nOnce created, the services are available to be consumed.\n\ndefaults:\n* API Health `GET http://localhost:8000/ping/`\n* Administration `GET|POST http://localhost:8000/admin/nodes/`\n\nby the user:\n* first endpoint `GET|POST|PUT|PATCH|DELETE http://localhost:8000/users/`\n* second endpoint `GET|POST|PUT|PATCH|DELETE http://localhost:8000/inventories/`\n\nDB config default `mongodb://apisrun:password@ip:27017/`\n\n[More Info](https://github.com/josesalasdev/apisrun)\n\n### Listing microservices\n\n```bash\napisrun list\n\n┏━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━┓\n┃ Container           ┃  Status ┃\n┡━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━┩\n│ myapi_apisrun       │ running │\n│ myapi_mongo_apisrun │ running │\n└─────────────────────┴─────────┘\n```\n\n### Kill microservices\n```bash\napisrun down\n\n✨ Your apis were removed. ✨\n```\n",
    'author': 'Jose Salas',
    'author_email': 'josephsalas.developer@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/josesalasdev/apisrun-cli/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
